/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EARDeployable.java 1363 2007-05-09 16:37:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployer.api;

import java.util.List;

import org.objectweb.easybeans.deployer.api.struct.EARInfo;

/**
 * Represents an EAR deployable.
 * @author Florent Benoit
 */
public interface EARDeployable extends EZBDeployable<EARDeployable> {

    /**
     * @return the list of the EJB deployables for this EAR.
     */
    List<EJBDeployable> getEJBDeployables();

    /**
     * @return the list of the EJB 2.1 deployables for this EAR.
     */
    List<EJB21Deployable> getEJB21Deployables();

    /**
     * @return the list of the EJB 3 deployables for this EAR.
     */
    List<EJB3Deployable> getEJB3Deployables();

    /**
     * @return the list of the War deployables for this EAR.
     */
    List<WARDeployable> getWARDeployables();

    /**
     * @return the list of the Rar deployables for this EAR.
     */
    List<RARDeployable> getRARDeployables();

    /**
     * @return the list of the Car deployables for this EAR.
     */
    List<CARDeployable> getCARDeployables();

    /**
     * @return the list of the Library deployables for this EAR.
     */
    List<LibDeployable> getLibDeployables();

    /**
     * @return EAR information (of the application.xml file).
     */
    EARInfo getEARInfo();
}
