/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EZBDeployable.java 1363 2007-05-09 16:37:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployer.api;

import org.objectweb.easybeans.api.EZBArchive;

/**
 * This interface is used to represent any deployment object that can be used within EasyBeans.<br>
 * The EJB/WEB/RAR/EAR, etc components should extend this interface.
 * @param <T> the type of the deployable.
 * @author Florent Benoit
  */
public interface EZBDeployable<T> {

    /**
     * Gets the Archive of this deployable object.
     * @return the archive for this deployable.
     */
    EZBArchive getArchive();

    /**
     * If the Deployable has been unpacked, return the initial archive.
     * @return the deployable before it is unpacked.
     */
    T getOriginalDeployable();

    /**
     * If the Deployable has been unpacked, return the unpacked deployable.
     * @return the unpacked deployable associated to this deployable.
     */
    T getUnpackedDeployable();

    /**
     * If the Deployable has been unpacked, sets the unpacked deployable.
     * @param unpackedDeployable the unpacked deployable associated to this deployable.
     */
    void setUnpackedDeployable(final T unpackedDeployable);

}
