/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: SessionFactoryIdentifier.java 1381 2007-05-14 13:42:06Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.container.session.management;

import org.objectweb.easybeans.api.EZBContainer;
import org.objectweb.easybeans.container.session.SessionFactory;
import org.objectweb.easybeans.jmx.MBeansException;
import org.objectweb.easybeans.jmx.MBeansHelper;
import org.objectweb.easybeans.jsr77.JSR77ManagementIdentifier;

/**
 * Generates an ObjectName for an session factory MBean.
 *
 * @author Guillaume Sauthier
 * @param <T> SessionFactory subclass
 */
public abstract class SessionFactoryIdentifier<T extends SessionFactory> extends
        JSR77ManagementIdentifier<T> {

    /**
     * {@inheritDoc}
     */
    public String getAdditionnalProperties(final T instance) {
        StringBuilder sb = new StringBuilder();
        // EJBModule=?
        EZBContainer container = instance.getContainer();
        String parent = null;
        try {
            parent = MBeansHelper.getInstance().getObjectName(container);
            sb.append(getParentNameProperty(parent));

            // TODO Add inherited properties ...
        } catch (MBeansException e) {
            getLogger().warn("Cannot retrieve parent ObjectName for ''{0}''", sb);
        }

        return sb.toString();
    }

    /**
     * {@inheritDoc}
     */
    public String getNamePropertyValue(final T instance) {
        return instance.getClassName();
    }

}
