/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AssemblyDescriptor.java 1188 2006-11-08 11:11:37Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.xml.struct;

import java.util.ArrayList;
import java.util.List;

import org.objectweb.easybeans.deployment.annotations.impl.JApplicationException;

/**
 * This class defines the implementation of the element assembly-descriptor.
 * @author Florent Benoit
 */
public class AssemblyDescriptor {

    /**
     * Name of this element.
     */
    public static final String NAME = "assembly-descriptor";

    /**
     * List of &lt;application-exception&gt; elements.
     */
    private List<JApplicationException> applicationExceptionList = null;

    /**
     * List of &lt;interceptor-binding&gt; elements.
     */
    private List<InterceptorBinding> interceptorBindingList = null;

    /**
     * Constructor.
     */
    public AssemblyDescriptor() {
        applicationExceptionList = new ArrayList<JApplicationException>();
        interceptorBindingList = new ArrayList<InterceptorBinding>();
    }

    /**
     * Gets the list of &lt;application-exception&gt; elements.
     * @return list of &lt;application-exception&gt; elements.
     */
    public List<JApplicationException> getApplicationExceptionList() {
        return applicationExceptionList;
    }

    /**
     * Adds a new &lt;application-exception&gt; element to assembly descriptor.
     * @param applicationException the &lt;application-exception&gt; element
     */
    public void addApplicationException(final JApplicationException applicationException) {
        applicationExceptionList.add(applicationException);
    }

    /**
     * Gets the list of &lt;interceptor-binding&gt; elements.
     * @return list of &lt;interceptor-binding&gt; elements.
     */
    public List<InterceptorBinding> getInterceptorBindingList() {
        return interceptorBindingList;
    }

    /**
     * Adds a new &lt;interceptor-binding&gt; element to assembly descriptor.
     * @param interceptorBinding the &lt;interceptor-binding&gt; element
     */
    public void addInterceptorBinding(final InterceptorBinding interceptorBinding) {
        interceptorBindingList.add(interceptorBinding);
    }
}
